@@ -56,7 +56,7 @@ class MongodbClient(AbstractClient):
 
 
     def CreateAccountUser(self, request):
-        """创建实例账号。
+        """本接口(CreateAccountUser)用于创建mongodb实例账号。
 
         :param request: Request instance for CreateAccountUser.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.CreateAccountUserRequest`
@@ -201,7 +201,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeAccountUsers(self, request):
-        """本接口(DescribeAccountUsers)用于获取当前实例的全部账号列表。
+        """本接口(DescribeAccountUsers)用于获取当前实例的全部账号。
 
         :param request: Request instance for DescribeAccountUsers.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeAccountUsersRequest`
@@ -984,7 +984,7 @@ class MongodbClient(AbstractClient):
 
 
     def SetAccountUserPrivilege(self, request):
-        """账户权限设置。
+        """本接口(SetAccountUserPrivilege)用于设置mongodb实例的账号权限。
 
         :param request: Request instance for SetAccountUserPrivilege.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.SetAccountUserPrivilegeRequest`
